@@ -84,6 +84,18 @@ sp.predict <- function(ggt.sp.obj, pred.coords, pred.covars, start=1, end, thin=
   }
   
   samples <- samples[,(ncol(K)+1):ncol(samples)]
+
+  ##if K.case is 3 then take the chol of each sample matrix.
+  A.chol <- function(x, m){
+    A <- matrix(0, m, m)
+    A[lower.tri(A, diag=TRUE)] <- x
+    A[upper.tri(A, diag=FALSE)] <- t(A)[upper.tri(A, diag=FALSE)]
+    t(chol(A))[lower.tri(A, diag=TRUE)]
+  }
+
+  if(K.case == 3){
+    K <- t(apply(K, 1, A.chol, m))
+  }
   
   K <- t(K) ##trans for easy BLAS
 
@@ -103,6 +115,12 @@ sp.predict <- function(ggt.sp.obj, pred.coords, pred.covars, start=1, end, thin=
     }
     
     samples <- samples[,(ncol(Psi)+1):ncol(samples)]
+
+    ##if Psi.case is 3 then take the chol of each sample matrix.
+    if(Psi.case == 3){
+      Psi <- t(apply(Psi, 1, A.chol, m))
+    }
+    
     Psi <- t(Psi) ##trans for easy BLAS
   }
 
