@@ -12,6 +12,7 @@
 #include <iostream>
 #include <iomanip>
 #include <string>
+#include <sstream>
 #include <vector>
 #include <map>
 using namespace std;
@@ -31,8 +32,19 @@ void mvrnorm(double *des, double *mu, double * cholCov, int dim);
 void mvrnorm(double *des, double *mu, double * cholCov, int dim, bool upper);
 
 void showMatrix(double *x, int xnrow, int xncol);
+void writeRMatrix(string outfile, double * a, int nrow, int ncol);
 
 SEXP getListElement (SEXP list, char *str);
 
-void myChol(double *a, double *p, int &n);
-void myCholInv(double *a, double *p, int &n, double &logdet);
+void zeros(double *x, int length);
+
+void identity(double *x, int &nrow);
+
+void kron(double *a, int &dima1, int &dima2, 
+	  double *b, int &dimb1, int &dimb2, 
+	  double *c, int &dimc1, int &dimc2);
+
+void setLowerChol(double *A, double *S, int dim);
+
+string toString(int &x);
+
